# auth-controller
AUTH_LOGIN = {
	"type": "post",
	"endpoint": "/auth/login",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}
AUTH_REFRESH_TOKEN = {
	"type": "post",
	"endpoint": "/auth/refresh-token",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}
AUTH_REQUEST_PASS = {
	"type": "post",
	"endpoint": "/auth/request-pass",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}
AUTH_RESET_PASS = {
	"type": "post",
	"endpoint": "/auth/reset-pass",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}
AUTH_RESTORE_PASS = {
	"type": "post",
	"endpoint": "/auth/restore-pass",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}
AUTH_SIGN_OUT = {
	"type": "post",
	"endpoint": "/auth/sign-out",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}
AUTH_SIGN_UP = {
	"type": "post",
	"endpoint": "/auth/sign-up",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}