# Worker: Uber
BUILD_MODEL_LUDWIG = {
	"type": "get",
	"endpoint": "/buildModelLudwig",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

BUILD_ORBIT_BTVC = {
	"type": "get",
	"endpoint": "/buildOrbitBTVC",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

BUILD_ORBIT_DLT = {
	"type": "get",
	"endpoint": "/buildOrbitDLT",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

BUILD_ORBIT_ETS = {
	"type": "get",
	"endpoint": "/buildOrbitETS",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

BUILD_ORBIT_LGT = {
	"type": "get",
	"endpoint": "/buildOrbitLGT",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}