VALIDATE = {
	"type": "get",
	"endpoint": "/validate",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

PROFILE = {
	"type": "get",
	"endpoint": "/profile",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

ARCHIVE = {
	"type": "get",
	"endpoint": "/archive",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

ACTIVITIES = {
	"type": "get",
	"endpoint": "/activities",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

POST_ACTIVITY = {
	"type": "post",
	"endpoint": "/activity",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}