SET_CREDENTIALS = {
	"type": "get",
	"endpoint": "/setCredentials",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

POST_SET_CREDENTIALS = {
	"type": "post",
	"endpoint": "/setCredentials",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}


SET_TENANT = {
	"type": "get",
	"endpoint": "/setTenant",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

MANAGE_TENANT = {
	"type": "get",
	"endpoint": "/manageTenant",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

CREATE_TENANT = {
	"type": "get",
	"endpoint": "/createTenant",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

POST_CREATE_TENANT = {
	"type": "post",
	"endpoint": "/createTenant",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

DELETE_TENANT = {
	"type": "get",
	"endpoint": "/deleteTenant",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

SET_CONFIGURATION = {
	"type": "get",
	"endpoint": "/setConfiguration",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

VALIDATE_TENANT = {
	"type": "get",
	"endpoint": "/validateTenant",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

GET_STATUS = {
	"type": "get",
	"endpoint": "/getStatus",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

LIST_TENANTS = {
	"type": "get",
	"endpoint": "/listTenants",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}