LOGIN = {
	"type": "get",
	"endpoint": "/login",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}
PING = {
	"type": "get",
	"endpoint": "/ping",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}