UPDATE_PROPERTIES = {
	"type": "post",
	"endpoint": "/updateProperties",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

UPLOAD_FILE = {
	"type": "post",
	"endpoint": "/upload",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

GET_FILE = {
	"type": "get",
	"endpoint": "/getFile",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

GET_FILE_TAIL = {
	"type": "get",
	"endpoint": "/getFileTail",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

GET_PROPERTY = {
	"type": "get",
	"endpoint": "/getProperty",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

GET_FILES = {
	"type": "get",
	"endpoint": "/getFiles",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"	
}

COPY_FILE = {
	"type": "get",
	"endpoint": "/copyFile",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

DOWNLOAD = {
	"type": "get",
	"endpoint": "/download",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

DELETE_FILE = {
	"type": "get",
	"endpoint": "/deleteFile",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

FILE_DELETE = {
	"type": "delete",
	"endpoint": "/file",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

CONVERT_REMOVE_NON_PRINTABLES = {
	"type": "get",
	"endpoint": "/convertRemoveNonPrintables",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

PROCESS_PUSH = {
	"type": "post",
	"endpoint": "/processPush",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

CONVERT_CSV_FROM_TO = {
	"type": "get",
	"endpoint": "/convertCsvFromTo",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}

CONVERT_TEXT_FILE_FROM_TO = {
	"type": "get",
	"endpoint": "/convertTextFileFromTo",
	"call_message": "{type} {endpoint}",
	"error_message": "{type} {endpoint} {response_code}"
}